translate.storage.xpi.FixedStringIO

Package translate :: Package storage :: Module xpi :: Class FixedStringIO |
[hide private]
[frames] | no frames]

# Class FixedStringIO

source code

Instance Methods | [hide private]
truncate(self, size=None) | source code
Inherited from `misc.wStringIO.StringIO`: `__init__`, `__iter__`, `close`, `flush`, `getvalue`, `isatty`, `next`, `read`, `readline`, `readlines`, `seek`, `tell`, `write`, `writelines`

Method Details | [hide private]

### truncate(self, size=None) | source code
Overrides: misc.wStringIO.StringIO.truncate